package edu.dartmouth.cs.testfirebasedemo;

import android.content.Intent;
import android.provider.ContactsContract;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.EditText;
import android.widget.ListAdapter;
import android.widget.ListView;
import android.widget.TextView;

import com.google.firebase.auth.FirebaseAuth;
import com.google.firebase.auth.FirebaseUser;
import com.google.firebase.database.DatabaseReference;
import com.google.firebase.database.FirebaseDatabase;
import com.google.firebase.database.Query;

import org.w3c.dom.Text;

public class MainActivity extends AppCompatActivity implements Button.OnClickListener,
        ListView.OnItemClickListener{
    private EditText text;
    private Button button;
    private ListView listView;
    private ArrayAdapter<String> adapter;

    private FirebaseAuth firebaseAuth;
    private FirebaseUser firebaseUser;
    private DatabaseReference databaseReference;
    private String userID;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        text = (EditText) findViewById(R.id.todoText);
        button = (Button) findViewById(R.id.addButton);
        button.setOnClickListener(this);
        listView = (ListView) findViewById(R.id.listView);
        listView.setOnItemClickListener(this);
        adapter = new ArrayAdapter<String>(this, android.R.layout.simple_expandable_list_item_1);
        listView.setAdapter(adapter);

        firebaseAuth = FirebaseAuth.getInstance();
        firebaseUser = firebaseAuth.getCurrentUser();
        databaseReference = FirebaseDatabase.getInstance().getReference();

        if(firebaseUser == null)
            Util.showActivity(this, LogInActivity.class);
        else{
            userID = firebaseUser.getUid();
            databaseReference = databaseReference.child("users").child(userID).child("items");
            databaseReference.addChildEventListener(new ListViewChildEventListener(adapter));
        }
    }

    public void onClick(View view){
//      Item item = new Item(text.getText().toString(), "abc");
//      databaseReference.push().setValue(item);
        String line = text.getText().toString();
        String key = databaseReference.push().getKey();
        databaseReference.child(key).child("title").setValue(line);
        text.setText("");
    }

    public void onItemClick(AdapterView<?> parent, View view, int position, long id){
        String line = ((TextView)view).getText().toString();
        Query query = databaseReference.orderByChild("title");
        query = query.equalTo(line);
//        query.addValueEventListener(new BackendValueEventListener());
        query.addListenerForSingleValueEvent(new BackendValueEventListener());//XD: addValueEventListener() keep listening to query or database reference it is attached to.But executes method immediately and after executing that method once, it stops listening to the reference location it is attached to.

    }

    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_main, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();

        //noinspection SimplifiableIfStatement
        if (id == R.id.action_logout) {
            firebaseAuth.signOut();
            Util.showActivity(this, LogInActivity.class);
        }

        return super.onOptionsItemSelected(item);
    }
}
